@@ -134,7 +134,6 @@ blogger.com videos (L<StreamFinder::Blogger>),
 brandnewtube.com and ugetube.com videos (L<StreamFinder::BrandNewTube>), 
 brighteon.com videos (L<StreamFinder::Brighteon>), 
 castbox.fm podcasts (L<StreamFinder::Castbox>), 
-goodpods.com podcasts (L<StreamFinder::Goodpods>), 
 podcasts.google.com podcasts (L<StreamFinder::Google>), 
 iheartradio.com radio stations and podcasts (L<StreamFinder::IHeartRadio>), 
 www.internetradio.com radio stations (L<StreamFinder::InternetRadio>), 
@@ -164,12 +163,12 @@ episode page to fetch streams from, as Podcastaddict.com has javascripted up
 their podcast pages now to the point that it is no longer possible to obtain 
 a playlist or first episode from them via our scripts.  
 
-NOTE:  StreamFinder::Reciva and StreamFinder::Radionomy have been removed, as 
-those sites have now closed down.
+NOTE:  StreamFinder::Goodpods has been removed, as that site has redone itself 
+in javascript as to no longer be scrapable for streams.
 
 NOTE:  For many sites, ie. Youtube, Vimeo, Apple, Spreaker, Castbox, Google, 
-etc. the "station" object actually refers to a specific video or podcast, but 
-functions the same way.  For some others, it may be a podcast episode.
+etc. the "station" object actually refers to a specific video or podcast 
+episode, but functions the same way.  
 
 Each site is supported by a separate subpackage (StreamFinder::I<Package>), 
 which is determined and selected based on the URL argument passed to it when 
@@ -537,14 +536,14 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '2.17';
+our $VERSION = '2.18';
 our $DEBUG = 0;
 
 require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw();
-my @supported_mods = (qw(Anystream Apple Bitchute Blogger BrandNewTube Brighteon Castbox Goodpods 
+my @supported_mods = (qw(Anystream Apple Bitchute Blogger BrandNewTube Brighteon Castbox  
 		Google IHeartRadio InternetRadio Odysee OnlineRadiobox Podbean PodcastAddict Podchaser 
 		RadioNet Rcast Rumble SermonAudio SoundCloud	Spreaker	Tunein Vimeo Youtube LinkTV Zeno));
 
@@ -640,9 +639,6 @@ sub new
 	} elsif ($url =~ m#\bsoundcloud\.# && $useit{'SoundCloud'}) {
 		eval { require 'StreamFinder/SoundCloud.pm'; $haveit = 1; };
 		return new StreamFinder::SoundCloud($url, @args)  if ($haveit);
-	} elsif ($url =~ m#\bgoodpods\.# && $useit{'Goodpods'}) {
-		eval { require 'StreamFinder/Goodpods.pm'; $haveit = 1; };
-		return new StreamFinder::Goodpods($url, @args)  if ($haveit);
 	} elsif ($url =~ m#\brcast\.# && $useit{'Rcast'}) {
 		eval { require 'StreamFinder/Rcast.pm'; $haveit = 1; };
 		return new StreamFinder::Rcast($url, @args)  if ($haveit);
